/*
 * Blink.c   Ver 0.1  (10. 3. 2024 9:47:21)
 *
 * Minimal working example for the FEI STU
 * Function:
 * a) setup serial interface and prepare stdio.h
 * b) on-board LED blink
 *
 * Definitions:
 *              ATmega328P
 *              F_CPU 16000000UL
 *              BAUDRATE 9600
 *
 * Tato verzia nepodporuje printf s float aritmetikou!
 * Ak ju pozadujete, treba pre float treba navyse:
 *     Toolchain -> AVR/GNU C ->  Miscelanous -> Other Linker Flags: -Wl,-u,vfprintf  -lprintf_flt  
 *
 * Documentation: http://senzor.robotika.sk/mips/Blink
 * 
 */ 


#include <util/delay.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include "light_ws2812.h"
#include "uart.h"


volatile int pos = 16;
struct cRGB led[16];

#define ws2812 PB0
#define ws2812_port B     // Data port 
#define ws2812_pin  0     // Data out pin
FILE mystdout = FDEV_SETUP_STREAM(uart_putc, NULL, _FDEV_SETUP_WRITE);


int main(void)
{
	uart_init();
	stdout = &mystdout;
	char ReceivedChar; 
   
	
	UBRR0 = 103;										// Set baud rate: Load the UBRR register

	UCSR0C = (1<<UCSZ01)|(1<<UCSZ00);					// Set format: 8data, 1stop bit 

	UCSR0B = (1 << RXEN0) | (1 << TXEN0);  
	// Uvtac obrzok :)
		led[0].r=0;led[0].g=0;led[0].b=50;		
		led[5].r=0;led[5].g=0;led[5].b=50;		
		led[10].r=0;led[10].g=0;led[10].b=50;		
		led[15].r=0;led[15].g=0;led[15].b=50;		
		led[3].r=0;led[3].g=0;led[3].b=50;		
		led[6].r=0;led[6].g=0;led[6].b=50;
		led[9].r=0;led[9].g=0;led[9].b=50;
		led[12].r=0;led[12].g=0;led[12].b=50;
		
		ws2812_setleds(led,0);
		ws2812_setleds(led,5);
		ws2812_setleds(led,10);
		ws2812_setleds_rgbw(led,15);
		ws2812_setleds(led,3);
		ws2812_setleds(led,6);
		ws2812_setleds(led,9);
		ws2812_setleds(led,12);
		
	
	_delay_ms(1500);
	
	//Vypn? vetky led
	uint8_t i;
    for(i=16; i>0; i--)
    {    
        led[i-1].r=0;led[i-1].g=0;led[i-1].b=0;
		ws2812_setleds(led,i);
    }
	
          while(1)
     {

        ReceivedChar = uart_getc();

        switch (ReceivedChar)
        {
                case '+':
                          led[pos].g-=50;                 // degreen actual position
                      pos++; if (pos >15) pos = 0;    // shift one position +check overflow
                   led[pos].g+=50;                 // write green to thenext one
                                  break;
                case '-':
                          led[pos].g-=50;
                      pos--; if (pos <0) pos = 15;
                   led[pos].g+=50;
                                  break;
                case '*':
                          led[pos].r=50;led[pos].b= 0;    // make red actual position
                                  break;
                case '/':
                          led[pos].r= 0;led[pos].b=50;    // make blue actual position
                                  break;
				case 'x':
									 for(i=16; i>0; i--)
					{    
						led[i-1].r=0;led[i-1].g=0;led[i-1].b=0;
					}break;
                default:
                          break;
        }

     ws2812_setleds(led,16);

        _delay_ms(50);                         // wait for 500ms.

        printf("Rec: %c  pos: %d \n",ReceivedChar,pos); // Vpis prijatho znaku a aktualnej pozcie 

     } 
		}
       
